@@ -2,6 +2,7 @@ import app from '../app';
 import Folder from '@joplin/lib/models/Folder';
 import BaseCommand from '../base-command';
 import setupCommand from '../setupCommand';
+import Setting from '@joplin/lib/models/Setting';
 
 // eslint-disable-next-line @typescript-eslint/ban-types, @typescript-eslint/no-explicit-any -- Old code before rule was applied, Old code before rule was applied
 export const setupCommandForTesting = (CommandClass: any, stdout: Function = null): BaseCommand => {
@@ -18,4 +19,9 @@ export const setupApplication = async () => {
 
 	// Some tests also need access to the Redux store
 	app().initRedux();
+
+	// Since the settings need to be loaded before the store is created, it will never
+	// receive the SETTING_UPDATE_ALL event, which means state.settings will not be
+	// initialised. So we manually call dispatchUpdateAll() to force an update.
+	Setting.dispatchUpdateAll();
 };
