@@ -1,7 +1,7 @@
 import styled from 'styled-components';
 
 // eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
-const Root = styled.div<any>`
+const Root = styled.h1<any>`
 	display: flex;
 	justify-content: ${props => props.justifyContent ? props.justifyContent : 'center'};
 	font-family: ${props => props.theme.fontFamily};
