@@ -1,3 +1,4 @@
+import { ToastType } from '@joplin/lib/shim';
 import * as React from 'react';
 
 export type PopupHandle = {
@@ -5,14 +6,13 @@ export type PopupHandle = {
 	scheduleDismiss(delay?: number): void;
 };
 
-export enum NotificationType {
-	Info = 'info',
-	Success = 'success',
-	Error = 'error',
-}
-
 export type NotificationContentCallback = ()=> React.ReactNode;
 
+// NotificationType is an alias for ToastType
+export type NotificationType = ToastType;
+// eslint-disable-next-line no-redeclare -- export const is necessary for creating an alias, this is not a redeclaration.
+export const NotificationType = ToastType;
+
 export interface PopupOptions {
 	type?: NotificationType;
 }
