@@ -9,6 +9,7 @@ interface Props {
 	listItems: ListItem[];
 	collapsedFolderIds: string[];
 	selectedIndex: number;
+	selectedIndexes: number[];
 	updateSelectedIndex: SetSelectedIndexCallback;
 }
 
@@ -49,13 +50,35 @@ const getParentOffset = (childIndex: number, listItems: ListItem[]): number|null
 	return null;
 };
 
+const findNextTypeAheadMatch = (selectedIndex: number, query: string, listItems: ListItem[]) => {
+	const normalize = (text: string) => text.trim().toLowerCase();
+	const matches = (item: ListItem) => {
+		return normalize(item.label).startsWith(normalize(query));
+	};
+
+	const indexBefore = listItems.slice(0, selectedIndex).findIndex(matches);
+	// Search in all results **after** the current. This prevents the current item from
+	// always being identified as the next match, if the user repeatedly presses the
+	// same key.
+	const startAfter = selectedIndex + 1;
+	let indexAfter = listItems.slice(startAfter).findIndex(matches);
+	if (indexAfter !== -1) {
+		indexAfter += startAfter;
+	}
+	// Prefer jumping to the next match, rather than the previous
+	const matchingIndex = indexAfter !== -1 ? indexAfter : indexBefore;
+	return matchingIndex;
+};
+
 const useOnSidebarKeyDownHandler = (props: Props) => {
-	const { updateSelectedIndex, listItems, selectedIndex, collapsedFolderIds, dispatch } = props;
+	const { updateSelectedIndex, listItems, selectedIndex, selectedIndexes, collapsedFolderIds, dispatch } = props;
 
 	return useCallback<KeyboardEventHandler<HTMLElement>>((event) => {
 		const selectedItem = listItems[selectedIndex];
 		let indexChange = 0;
 
+		const ctrlAltOrMeta = event.ctrlKey || event.altKey || event.metaKey;
+
 		if (selectedItem && isToggleShortcut(event.code, selectedItem, collapsedFolderIds)) {
 			event.preventDefault();
 
@@ -82,16 +105,32 @@ const useOnSidebarKeyDownHandler = (props: Props) => {
 			indexChange = 1;
 		} else if ((event.ctrlKey || event.metaKey) && event.code === 'KeyA') { // ctrl+a or cmd+a
 			event.preventDefault();
+		} else if (event.code === 'Home') {
+			event.preventDefault();
+			updateSelectedIndex(0, { extend: false });
+			indexChange = 0;
+		} else if (event.code === 'End') {
+			event.preventDefault();
+			updateSelectedIndex(listItems.length - 1, { extend: false });
+			indexChange = 0;
+		} else if (event.code === 'Escape' && selectedIndexes.length > 1) {
+			event.preventDefault();
+			updateSelectedIndex(selectedIndex, { extend: false });
 		} else if (event.code === 'Enter' && !event.shiftKey) {
 			event.preventDefault();
 			void CommandService.instance().execute('focusElement', 'noteList');
+		} else if (selectedIndex && selectedIndex >= 0 && event.key.length === 1 && !ctrlAltOrMeta) {
+			const nextMatch = findNextTypeAheadMatch(selectedIndex, event.key, listItems);
+			if (nextMatch !== -1) {
+				indexChange = nextMatch - selectedIndex;
+			}
 		}
 
 		if (indexChange !== 0) {
 			event.preventDefault();
-			updateSelectedIndex(selectedIndex + indexChange);
+			updateSelectedIndex(selectedIndex + indexChange, { extend: event.shiftKey });
 		}
-	}, [selectedIndex, collapsedFolderIds, listItems, updateSelectedIndex, dispatch]);
+	}, [selectedIndex, selectedIndexes, collapsedFolderIds, listItems, updateSelectedIndex, dispatch]);
 };
 
 export default useOnSidebarKeyDownHandler;
