@@ -16,6 +16,8 @@ export enum ListItemType {
 
 interface BaseListItem {
 	key: string;
+	// Used for typeahead
+	label: string;
 	depth: number;
 	hasChildren: boolean;
 }
@@ -26,7 +28,6 @@ interface ToplevelListItem extends BaseListItem {
 
 export interface HeaderListItem extends ToplevelListItem {
 	kind: ListItemType.Header;
-	label: string;
 	expanded: boolean;
 	iconName: string;
 	id: HeaderId;
@@ -56,8 +57,10 @@ export interface SpacerListItem extends ToplevelListItem {
 
 export type ListItem = HeaderListItem|AllNotesListItem|TagListItem|FolderListItem|SpacerListItem;
 
-
-export type SetSelectedIndexCallback = (newIndex: number)=> void;
+interface SetSelectedIndexOptions {
+	extend: boolean;
+}
+export type SetSelectedIndexCallback = (newIndex: number, options: SetSelectedIndexOptions)=> void;
 
 
 export type ItemDragListener = DragEventHandler<HTMLElement>;
