@@ -12,6 +12,8 @@ import { WindowIdContext } from '../../gui/NewWindowOrIFrame';
 import useSubmitHandler from './hooks/useSubmitHandler';
 import useFormData from './hooks/useFormData';
 import Setting from '@joplin/lib/models/Setting';
+import getAssetPath from '../../utils/getAssetPath';
+import { toForwardSlashes } from '@joplin/utils/path';
 
 const logger = Logger.create('UserWebview');
 
@@ -27,12 +29,9 @@ export interface Props {
 	borderBottom?: boolean;
 	// eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
 	theme?: any;
-	// eslint-disable-next-line @typescript-eslint/ban-types -- Old code before rule was applied
-	onSubmit?: Function;
-	// eslint-disable-next-line @typescript-eslint/ban-types -- Old code before rule was applied
-	onDismiss?: Function;
-	// eslint-disable-next-line @typescript-eslint/ban-types -- Old code before rule was applied
-	onReady?: Function;
+	onSubmit?: ()=> void;
+	onDismiss?: ()=> void;
+	onReady?: ()=> void;
 }
 
 // eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
@@ -124,7 +123,7 @@ function UserWebview(props: Props, ref: any) {
 
 	const src = useMemo(() => {
 		const isolate = Setting.value('featureFlag.plugins.isolatePluginWebViews');
-		const path = `${__dirname}/UserWebviewIndex.html`;
+		const path = toForwardSlashes(getAssetPath('services/plugins/UserWebviewIndex.html'));
 		if (isolate) {
 			return `joplin-content://plugin-webview/${path}`;
 		} else {
