@@ -24,7 +24,7 @@ export interface DialogControl {
 	info(message: string): Promise<void>;
 	error(message: string): Promise<void>;
 	prompt(title: string, message: string, buttons?: PromptButtonSpec[], options?: PromptOptions): void;
-	promptForText(message: string): Promise<string>;
+	promptForText(message: string, initialValue?: string): Promise<string>;
 	showMenu<IdType>(title: string, choices: MenuChoice<IdType>[]): Promise<IdType>;
 }
 
@@ -47,6 +47,7 @@ export interface TextInputDialogData {
 	type: DialogType.TextInput;
 	key: string;
 	message: string;
+	initialValue?: string;
 	onSubmit: (text: string)=> void;
 	onDismiss: ()=> void;
 }
