@@ -6,7 +6,10 @@ import { themeStyle } from './global-style';
 import Modal from './Modal';
 import { _ } from '@joplin/lib/locale';
 
-export enum DialogSize {
+export enum DialogVariant {
+	// Small width, auto-determined height
+	SmallResize = 'small-resize',
+
 	Small = 'small',
 
 	// Ideal for panels and dialogs that should be fullscreen even on large devices
@@ -20,34 +23,62 @@ interface Props {
 	containerStyle?: ViewStyle;
 	children: React.ReactNode;
 	heading?: string;
+	scrollOverflow?: boolean;
 
-	size: DialogSize;
+	size: DialogVariant;
 }
 
-const useStyles = (themeId: number, containerStyle: ViewStyle, size: DialogSize) => {
+const useStyles = (themeId: number, containerStyle: ViewStyle, size: DialogVariant) => {
 	const windowSize = useWindowDimensions();
 
 	return useMemo(() => {
 		const theme = themeStyle(themeId);
 
-		const maxWidth = size === DialogSize.Large ? windowSize.width : 500;
-		const maxHeight = size === DialogSize.Large ? windowSize.height : 700;
+		const maxWidth = size === DialogVariant.Large ? windowSize.width : 500;
+		const maxHeight = size === DialogVariant.Large ? windowSize.height : 700;
+
+		const dialogSizing: ViewStyle = {
+			width: '100%',
+
+			...(size !== DialogVariant.SmallResize ? {
+				height: '100%',
+			} : { }),
+		};
 
 		return StyleSheet.create({
-			closeButtonContainer: {
+			closeButtonRow: {
 				flexDirection: 'row',
 				justifyContent: 'space-between',
 				alignContent: 'center',
+				marginBottom: 8,
+			},
+			closeButtonRowWithHeading: {
+				marginBottom: 16,
+			},
+			closeButton: {
+				margin: 0,
+			},
+			// Ensure that the close button is aligned with the center of the header:
+			// Make its container smaller and center it.
+			closeButtonWrapper: {
+				height: 18,
+				flexDirection: 'column',
+				justifyContent: 'center',
+				alignSelf: 'center',
 			},
 			heading: {
-				alignSelf: 'center',
+				// Without flexShrink/flexGrow, the heading can push the close button
+				// outside of the dialog.
+				flexShrink: 1,
+				flexGrow: 1,
+			},
+			modalBackground: {
+				justifyContent: 'center',
 			},
 			dialogContainer: {
 				maxHeight,
 				maxWidth,
-				width: '100%',
-				height: '100%',
-				flexShrink: 1,
+				...dialogSizing,
 
 				// Center
 				marginLeft: 'auto',
@@ -58,11 +89,11 @@ const useStyles = (themeId: number, containerStyle: ViewStyle, size: DialogSize)
 				...containerStyle,
 			},
 			dialogSurface: {
-				borderRadius: 12,
+				borderRadius: 24,
 				backgroundColor: theme.backgroundColor,
-				padding: 10,
-				width: '100%',
-				height: '100%',
+				paddingHorizontal: 16,
+				paddingVertical: 24,
+				...dialogSizing,
 			},
 		});
 	}, [themeId, windowSize.width, windowSize.height, containerStyle, size]);
@@ -76,13 +107,16 @@ const DismissibleDialog: React.FC<Props> = props => {
 		<Text variant='headlineSmall' role='heading' style={styles.heading}>{props.heading}</Text>
 	) : null;
 	const closeButtonRow = (
-		<View style={styles.closeButtonContainer}>
+		<View style={[styles.closeButtonRow, !!props.heading && styles.closeButtonRowWithHeading]}>
 			{heading ?? <View/>}
-			<IconButton
-				icon='close'
-				accessibilityLabel={_('Close')}
-				onPress={props.onDismiss}
-			/>
+			<View style={styles.closeButtonWrapper}>
+				<IconButton
+					icon='close'
+					accessibilityLabel={_('Close')}
+					onPress={props.onDismiss}
+					style={styles.closeButton}
+				/>
+			</View>
 		</View>
 	);
 
@@ -92,9 +126,13 @@ const DismissibleDialog: React.FC<Props> = props => {
 			onDismiss={props.onDismiss}
 			onRequestClose={props.onDismiss}
 			containerStyle={styles.dialogContainer}
+			modalBackgroundStyle={styles.modalBackground}
 			animationType='fade'
 			backgroundColor={theme.backgroundColorTransparent2}
 			transparent={true}
+			scrollOverflow={props.scrollOverflow}
+			// Allows the modal background to extend under the statusbar
+			statusBarTranslucent
 		>
 			<Surface style={styles.dialogSurface} elevation={1}>
 				{closeButtonRow}
