@@ -1,6 +1,6 @@
 import * as React from 'react';
 import { RefObject, useCallback, useMemo, useRef, useState } from 'react';
-import { GestureResponderEvent, Modal, ModalProps, Platform, Pressable, ScrollView, ScrollViewProps, StyleSheet, View, ViewStyle } from 'react-native';
+import { GestureResponderEvent, KeyboardAvoidingView, Modal, ModalProps, Platform, Pressable, ScrollView, ScrollViewProps, StyleSheet, View, ViewStyle } from 'react-native';
 import FocusControl from './accessibility/FocusControl/FocusControl';
 import { msleep, Second } from '@joplin/utils/time';
 import useAsyncEffect from '@joplin/lib/hooks/useAsyncEffect';
@@ -8,7 +8,7 @@ import { ModalState } from './accessibility/FocusControl/types';
 import useSafeAreaPadding from '../utils/hooks/useSafeAreaPadding';
 import { _ } from '@joplin/lib/locale';
 
-interface ModalElementProps extends ModalProps {
+export interface ModalElementProps extends ModalProps {
 	children: React.ReactNode;
 	containerStyle?: ViewStyle;
 	backgroundColor?: string;
@@ -27,11 +27,23 @@ interface ModalElementProps extends ModalProps {
 const useStyles = (hasScrollView: boolean, backgroundColor: string|undefined) => {
 	const safeAreaPadding = useSafeAreaPadding();
 	return useMemo(() => {
+		// On Android, the top-level container seems to need to be absolutely positioned
+		// to prevent it from being larger than the screen size:
+		const absoluteFill = {
+			position: 'absolute',
+			top: 0,
+			left: 0,
+			right: 0,
+			bottom: 0,
+		} satisfies ViewStyle;
+
 		return StyleSheet.create({
 			modalBackground: {
 				...safeAreaPadding,
-				flexGrow: 1,
-				flexShrink: 1,
+				...(hasScrollView ? {
+					flexGrow: 1,
+					flexShrink: 1,
+				} : absoluteFill),
 
 				// When hasScrollView, the modal background is wrapped in a ScrollView. In this case, it's
 				// possible to scroll content outside the background into view. To prevent the edge of the
@@ -39,6 +51,10 @@ const useStyles = (hasScrollView: boolean, backgroundColor: string|undefined) =>
 				// instead:
 				backgroundColor: hasScrollView ? null : backgroundColor,
 			},
+			keyboardAvoidingView: {
+				...absoluteFill,
+				flex: 1,
+			},
 			modalScrollView: {
 				backgroundColor,
 				flexGrow: 1,
@@ -159,11 +175,13 @@ const ModalElement: React.FC<ModalElementProps> = ({
 				{...modalProps}
 			>
 				{scrollOverflow ? (
-					<ScrollView
-						{...extraScrollViewProps}
-						style={[styles.modalScrollView, extraScrollViewProps.style]}
-						contentContainerStyle={[styles.modalScrollViewContent, extraScrollViewProps.contentContainerStyle]}
-					>{contentAndBackdrop}</ScrollView>
+					<KeyboardAvoidingView behavior='padding' style={styles.keyboardAvoidingView}>
+						<ScrollView
+							{...extraScrollViewProps}
+							style={[styles.modalScrollView, extraScrollViewProps.style]}
+							contentContainerStyle={[styles.modalScrollViewContent, extraScrollViewProps.contentContainerStyle]}
+						>{contentAndBackdrop}</ScrollView>
+					</KeyboardAvoidingView>
 				) : contentAndBackdrop}
 			</Modal>
 		</FocusControl.ModalWrapper>
