@@ -1,4 +1,4 @@
 import { OnMessageEvent } from '../ExtendedWebView/types';
 
-export type OnScrollCallback = (scrollTop: number)=> void;
+export { OnScrollCallback } from '../../contentScripts/rendererBundle/types';
 export type OnWebViewMessageHandler = (event: OnMessageEvent)=> void;
