@@ -7,13 +7,13 @@ import { WebViewControl } from '../ExtendedWebView/types';
 import * as React from 'react';
 import { Ref, RefObject, useEffect, useImperativeHandle } from 'react';
 import { useMemo, useState, useCallback, useRef } from 'react';
-import { LayoutChangeEvent, View, ViewStyle } from 'react-native';
+import { LayoutChangeEvent, Platform, View, ViewStyle } from 'react-native';
 import { editorFont } from '../global-style';
 
 import { EditorControl as EditorBodyControl, ContentScriptData } from '@joplin/editor/types';
 import { EditorControl, EditorSettings, EditorType } from './types';
 import { _ } from '@joplin/lib/locale';
-import { ChangeEvent, EditorEvent, EditorEventType, SelectionRangeChangeEvent, UndoRedoDepthChangeEvent } from '@joplin/editor/events';
+import { ChangeEvent, EditorEvent, EditorEventType, EditorScrolledEvent, SelectionRangeChangeEvent, UndoRedoDepthChangeEvent } from '@joplin/editor/events';
 import { EditorCommandType, EditorKeymap, EditorLanguageType, SearchState } from '@joplin/editor/types';
 import SelectionFormatting, { defaultSelectionFormatting } from '@joplin/editor/SelectionFormatting';
 import { PluginStates } from '@joplin/lib/services/plugins/reducer';
@@ -32,16 +32,25 @@ import { dirname } from '@joplin/utils/path';
 import { toFileExtension } from '@joplin/lib/mime-utils';
 import { MarkupLanguage } from '@joplin/renderer';
 import WarningBanner from './WarningBanner';
+import useIsScreenReaderEnabled from '../../utils/hooks/useIsScreenReaderEnabled';
+import Logger from '@joplin/utils/Logger';
+import { Second } from '@joplin/utils/time';
+import useDebounced from '../../utils/hooks/useDebounced';
 
-type ChangeEventHandler = (event: ChangeEvent)=> void;
-type UndoRedoDepthChangeHandler = (event: UndoRedoDepthChangeEvent)=> void;
-type SelectionChangeEventHandler = (event: SelectionRangeChangeEvent)=> void;
-type OnAttachCallback = (filePath?: string)=> Promise<void>;
+const logger = Logger.create('NoteEditor');
+
+type OnChange = (event: ChangeEvent)=> void;
+type OnSearchVisibleChange = (visible: boolean)=> void;
+type OnScroll = (event: EditorScrolledEvent)=> void;
+type OnUndoRedoDepthChange = (event: UndoRedoDepthChangeEvent)=> void;
+type OnSelectionChange = (event: SelectionRangeChangeEvent)=> void;
+type OnAttach = (filePath?: string)=> Promise<void>;
 
 interface Props {
 	ref: Ref<EditorControl>;
 	themeId: number;
 	initialText: string;
+	initialScroll: number;
 	mode: EditorType;
 	markupLanguage: MarkupLanguage;
 	noteId: string;
@@ -54,10 +63,12 @@ interface Props {
 	plugins: PluginStates;
 	noteResources: ResourceInfos;
 
-	onChange: ChangeEventHandler;
-	onSelectionChange: SelectionChangeEventHandler;
-	onUndoRedoDepthChange: UndoRedoDepthChangeHandler;
-	onAttach: OnAttachCallback;
+	onScroll: OnScroll;
+	onChange: OnChange;
+	onSearchVisibleChange: OnSearchVisibleChange;
+	onSelectionChange: OnSelectionChange;
+	onUndoRedoDepthChange: OnUndoRedoDepthChange;
+	onAttach: OnAttach;
 }
 
 function fontFamilyFromSettings() {
@@ -86,6 +97,8 @@ function editorTheme(themeId: number) {
 	};
 }
 
+const noteEditorSearchChangeSource = 'joplin.noteEditor.setSearchState';
+
 type OnSetVisibleCallback = (visible: boolean)=> void;
 type OnSearchStateChangeCallback = (state: SearchState)=> void;
 const useEditorControl = (
@@ -100,7 +113,7 @@ const useEditorControl = (
 		};
 
 		const setSearchStateCallback = (state: SearchState) => {
-			editorRef.current.setSearchState(state);
+			editorRef.current.setSearchState(state, noteEditorSearchChangeSource);
 			setSearchState(state);
 		};
 
@@ -110,6 +123,7 @@ const useEditorControl = (
 			},
 			// eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
 			execCommand(command, ...args: any[]) {
+				logger.debug('execCommand', command);
 				return editorRef.current.execCommand(command, ...args);
 			},
 
@@ -229,8 +243,8 @@ const useEditorControl = (
 				setSearchState: setSearchStateCallback,
 			},
 
-			onResourceDownloaded: (id: string) => {
-				editorRef.current.onResourceDownloaded(id);
+			onResourceChanged: (id: string) => {
+				editorRef.current.onResourceChanged(id);
 			},
 
 			remove: () => {
@@ -242,9 +256,31 @@ const useEditorControl = (
 	}, [webviewRef, editorRef, setLinkDialogVisible, setSearchState]);
 };
 
+const useHighlightActiveLine = () => {
+	const screenReaderEnabled = useIsScreenReaderEnabled();
+	// Guess whether highlighting the active line can be enabled without triggering
+	// https://github.com/codemirror/dev/issues/1559.
+	const canHighlight = Platform.OS !== 'ios' || !screenReaderEnabled;
+	return canHighlight && Setting.value('editor.highlightActiveLine');
+};
+
+const useHasSpaceForToolbar = () => {
+	const [hasSpaceForToolbar, setHasSpaceForToolbar] = useState(true);
+
+	const onContainerLayout = useCallback((event: LayoutChangeEvent) => {
+		const containerHeight = event.nativeEvent.layout.height;
+
+		setHasSpaceForToolbar(containerHeight >= 140);
+	}, []);
+
+	const debouncedHasSpaceForToolbar = useDebounced(hasSpaceForToolbar, Second / 4);
+	return { hasSpaceForToolbar: debouncedHasSpaceForToolbar, onContainerLayout };
+};
+
 function NoteEditor(props: Props) {
 	const webviewRef = useRef<WebViewControl>(null);
 
+	const highlightActiveLine = useHighlightActiveLine();
 	const editorSettings: EditorSettings = useMemo(() => ({
 		themeData: editorTheme(props.themeId),
 		markdownMarkEnabled: Setting.value('markdown.plugin.mark'),
@@ -255,8 +291,10 @@ function NoteEditor(props: Props) {
 		language: props.markupLanguage === MarkupLanguage.Html ? EditorLanguageType.Html : EditorLanguageType.Markdown,
 		useExternalSearch: true,
 		readOnly: props.readOnly,
+		highlightActiveLine,
 
 		keymap: EditorKeymap.Default,
+		preferMacShortcuts: shim.mobilePlatform() === 'ios',
 
 		automatchBraces: false,
 		ignoreModifiers: false,
@@ -267,13 +305,14 @@ function NoteEditor(props: Props) {
 		indentWithTabs: true,
 
 		editorLabel: _('Markdown editor'),
-	}), [props.themeId, props.readOnly, props.markupLanguage]);
+	}), [props.themeId, props.readOnly, props.markupLanguage, highlightActiveLine]);
 
 	const [selectionState, setSelectionState] = useState<SelectionFormatting>(defaultSelectionFormatting);
 	const [linkDialogVisible, setLinkDialogVisible] = useState(false);
 	const [searchState, setSearchState] = useState(defaultSearchState);
 
 	const editorControlRef = useRef<EditorControl|null>(null);
+	const lastSearchVisibleRef = useRef<boolean|undefined>(undefined);
 	const onEditorEvent = (event: EditorEvent) => {
 		let exhaustivenessCheck: never;
 		switch (event.kind) {
@@ -295,19 +334,38 @@ function NoteEditor(props: Props) {
 		case EditorEventType.FollowLink:
 			void CommandService.instance().execute('openItem', event.link);
 			break;
-		case EditorEventType.UpdateSearchDialog:
-			setSearchState(event.searchState);
+		case EditorEventType.UpdateSearchDialog: {
+			const hasExternalChange = (
+				event.changeSources.length !== 1
+				|| event.changeSources[0] !== noteEditorSearchChangeSource
+			);
 
-			if (event.searchState.dialogVisible) {
-				editorControl.searchControl.showSearch();
-			} else {
-				editorControl.searchControl.hideSearch();
+			// If the change to the search was done by this editor, it was already applied to the
+			// search state. Skipping the update in this case also helps avoid overwriting the
+			// search state with an older value.
+			const showSearch = event.searchState.dialogVisible ?? lastSearchVisibleRef.current;
+			if (hasExternalChange) {
+				setSearchState(event.searchState);
+
+				if (showSearch) {
+					editorControl.searchControl.showSearch();
+				} else {
+					editorControl.searchControl.hideSearch();
+				}
+			}
+
+			if (showSearch !== lastSearchVisibleRef.current) {
+				props.onSearchVisibleChange(showSearch);
+				lastSearchVisibleRef.current = showSearch;
 			}
 			break;
+		}
 		case EditorEventType.Remove:
-		case EditorEventType.Scroll:
 			// Not handled
 			break;
+		case EditorEventType.Scroll:
+			props.onScroll(event);
+			break;
 		default:
 			exhaustivenessCheck = event;
 			return exhaustivenessCheck;
@@ -331,10 +389,18 @@ function NoteEditor(props: Props) {
 		const isDownloaded = (resourceInfos: ResourceInfos, resourceId: string) => {
 			return resourceInfos[resourceId]?.localState?.fetch_status === Resource.FETCH_STATUS_DONE;
 		};
+		const isEncrypted = (resourceInfos: ResourceInfos, resourceId: string) => {
+			return resourceInfos[resourceId]?.item?.encryption_blob_encrypted === 1;
+		};
 		for (const key in props.noteResources) {
 			const wasDownloaded = isDownloaded(lastNoteResources.current, key);
-			if (!wasDownloaded && isDownloaded(props.noteResources, key)) {
-				editorControl.onResourceDownloaded(key);
+			const hasDownloaded = !wasDownloaded && isDownloaded(props.noteResources, key);
+
+			const wasEncrypted = isEncrypted(lastNoteResources.current, key);
+			const hasDecrypted = wasEncrypted && !isEncrypted(props.noteResources, key);
+
+			if (hasDownloaded || hasDecrypted) {
+				editorControl.onResourceChanged(key);
 			}
 		}
 	}, [props.noteResources, editorControl]);
@@ -345,18 +411,6 @@ function NoteEditor(props: Props) {
 		return editorControl;
 	});
 
-	const [hasSpaceForToolbar, setHasSpaceForToolbar] = useState(true);
-	const toolbarEnabled = props.toolbarEnabled && hasSpaceForToolbar;
-
-	const onContainerLayout = useCallback((event: LayoutChangeEvent) => {
-		const containerHeight = event.nativeEvent.layout.height;
-
-		if (containerHeight < 140) {
-			setHasSpaceForToolbar(false);
-		} else {
-			setHasSpaceForToolbar(true);
-		}
-	}, []);
 
 	const onAttach = useCallback(async (type: string, base64: string) => {
 		const tempFilePath = join(Setting.value('tempDir'), `paste.${uuid.createNano()}.${toFileExtension(type)}`);
@@ -374,7 +428,11 @@ function NoteEditor(props: Props) {
 		searchVisible: searchState.dialogVisible,
 	}), [selectionState, searchState.dialogVisible]);
 
+
+	const { hasSpaceForToolbar, onContainerLayout } = useHasSpaceForToolbar();
+	const toolbarEnabled = props.toolbarEnabled && hasSpaceForToolbar;
 	const toolbar = <EditorToolbar editorState={toolbarEditorState} />;
+
 	const EditorComponent = props.mode === EditorType.Markdown ? MarkdownEditor : RichTextEditor;
 
 	return (
@@ -405,6 +463,7 @@ function NoteEditor(props: Props) {
 					noteHash={props.noteHash}
 					initialText={props.initialText}
 					initialSelection={props.initialSelection}
+					initialScroll={props.initialScroll}
 					editorSettings={editorSettings}
 					globalSearch={props.globalSearch}
 					onEditorEvent={onEditorEvent}
