@@ -7,7 +7,7 @@ import NoteBodyViewer from '../../NoteBodyViewer/NoteBodyViewer';
 import checkPermissions from '../../../utils/checkPermissions';
 import NoteEditor from '../../NoteEditor/NoteEditor';
 import * as React from 'react';
-import { Keyboard, View, TextInput, StyleSheet, Linking, Share, NativeSyntheticEvent } from 'react-native';
+import { Keyboard, View, TextInput, StyleSheet, Linking, Share, NativeSyntheticEvent, useWindowDimensions } from 'react-native';
 import { Platform, PermissionsAndroid } from 'react-native';
 import { connect } from 'react-redux';
 import Note from '@joplin/lib/models/Note';
@@ -73,6 +73,14 @@ import { defaultWindowId } from '@joplin/lib/reducer';
 import useVisiblePluginEditorViewIds from '@joplin/lib/hooks/plugins/useVisiblePluginEditorViewIds';
 import { SelectionRange } from '../../../contentScripts/markdownEditorBundle/types';
 import { EditorType } from '../../NoteEditor/types';
+import { IconButton } from 'react-native-paper';
+import { writeTextToCacheFile } from '../../../utils/ShareUtils';
+import shareFile from '../../../utils/shareFile';
+import NotePositionService from '@joplin/lib/services/NotePositionService';
+import useKeyboardState from '../../../utils/hooks/useKeyboardState';
+import VoiceTyping from '../../../services/voiceTyping/VoiceTyping';
+import useDebounced from '../../../utils/hooks/useDebounced';
+import { Second } from '@joplin/utils/time';
 
 // eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
 const emptyArray: any[] = [];
@@ -117,12 +125,14 @@ interface Props extends BaseProps {
 interface ComponentProps extends Props {
 	dialogs: DialogControl;
 	visibleEditorPluginIds: string[];
+	lowVerticalSpace: boolean;
 }
 
 interface State {
 	note: NoteEntity;
 	mode: NoteViewerMode;
 	readOnly: boolean;
+	searchVisible: boolean;
 	folder: FolderEntity|null;
 	// eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
 	lastSavedNote: any;
@@ -148,8 +158,11 @@ interface State {
 	};
 
 	showSpeechToTextDialog: boolean;
+	multiline: boolean;
 }
 
+type ScrollEventSlice = { fraction: number };
+
 class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> implements BaseNoteScreenComponent<State> {
 	// This isn't in this.state because we don't want changing scroll to trigger
 	// a re-render.
@@ -207,6 +220,7 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 			showCamera: false,
 			showImageEditor: false,
 			showAudioRecorder: false,
+			searchVisible: false,
 			imageEditorResource: null,
 			noteResources: {},
 			imageEditorResourceFilepath: null,
@@ -219,8 +233,16 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 			},
 
 			showSpeechToTextDialog: false,
+			multiline: false,
 		};
 
+		const initialCursorLocation = NotePositionService.instance().getCursorPosition(props.noteId, defaultWindowId).markdown;
+		if (initialCursorLocation) {
+			this.selection = { start: initialCursorLocation, end: initialCursorLocation };
+		}
+		const initialScroll = NotePositionService.instance().getScrollPercent(props.noteId, defaultWindowId);
+		this.lastBodyScroll = initialScroll;
+
 		this.titleTextFieldRef = React.createRef();
 
 		this.saveActionQueues_ = {};
@@ -374,6 +396,9 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		return this.props.useEditorBeta;
 	}
 
+	private onSearchVisibleChange_ = (visible: boolean) => {
+		this.setState({ searchVisible: visible });
+	};
 
 	private onUndoRedoDepthChange(event: UndoRedoDepthChangeEvent) {
 		if (this.useEditorBeta()) {
@@ -508,9 +533,9 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 			flexDirection: 'row',
 			flexBasis: 'auto',
 			paddingLeft: theme.marginLeft,
-			paddingRight: theme.marginRight,
 			borderBottomColor: theme.dividerColor,
 			borderBottomWidth: 1,
+			maxHeight: '40%',
 		};
 
 		styles.titleContainerTodo = { ...styles.titleContainer };
@@ -541,8 +566,17 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		if (Platform.OS === 'web') return;
 
 		const response = await checkPermissions(PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION, {
-			message: _('In order to associate a geo-location with the note, the app needs your permission to access your location.\n\nYou may turn off this option at any time in the Configuration screen.'),
-			title: _('Permission needed'),
+			onRequestConfirmation: async () => {
+				const yesIndex = 0;
+				const result = await shim.showMessageBox(
+					_('Joplin supports saving the location at which notes are saved or created. Do you want to enable it? This can be changed at any time in settings.'),
+					{
+						buttons: [_('Yes'), _('No')],
+						title: _('Save geolocation?'),
+					},
+				);
+				return result === yesIndex;
+			},
 		});
 
 		// If the user simply pressed "Deny", we don't automatically switch it off because they might accept
@@ -646,6 +680,17 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 			});
 		}
 
+		// Reset undo/redo button state when switching to edit mode or when switching between markdown and rich text editors, since the editor is
+		// recreated and loses its undo/redo history
+		if (this.state.mode === 'edit' && (prevState.mode !== this.state.mode || prevProps.editorType !== this.props.editorType)) {
+			this.setState({
+				undoRedoButtonState: {
+					canUndo: false,
+					canRedo: false,
+				},
+			});
+		}
+
 		if (prevProps.noteId && this.props.noteId && prevProps.noteId !== this.props.noteId) {
 			// Easier to just go back, then go to the note since
 			// the Note screen doesn't handle reloading a different note
@@ -677,6 +722,10 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		if (prevState.note.body !== this.state.note.body) {
 			this.emitEditorPluginUpdate_();
 		}
+
+		if (prevState.multiline !== this.state.multiline && this.titleTextFieldRef.current) {
+			focus('Note::focusUpdate::title', this.titleTextFieldRef.current);
+		}
 	}
 
 	public componentWillUnmount() {
@@ -701,7 +750,13 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 	}
 
 	private title_changeText(text: string) {
-		shared.noteComponent_change(this, 'title', text);
+		let newText = text;
+		if (Platform.OS !== 'web') {
+			// Manipulating the underlying text inside of onChangeText causes issues with the cursor position jumping to the end while typing
+			// when the Web app is being used on a desktop OS, so providing a toggle to expand the title field can only be done on mobile platforms
+			newText = text.replace(/(\r\n|\n|\r)/gm, ' ');
+		}
+		shared.noteComponent_change(this, 'title', newText);
 		this.setState({ newAndNoTitleChangeNoteId: null });
 	}
 
@@ -735,8 +790,12 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		this.selection = event.nativeEvent.selection;
 	};
 
-	private onMarkdownEditorSelectionChange = (event: SelectionRangeChangeEvent) => {
+	private onEditorSelectionChange = (event: SelectionRangeChangeEvent) => {
 		this.selection = { start: event.from, end: event.to };
+
+		NotePositionService.instance().updateCursorPosition(
+			this.props.noteId, defaultWindowId, { markdown: event.from },
+		);
 	};
 
 	public makeSaveAction(state: State) {
@@ -1049,10 +1108,33 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 	}
 
 	private async share_onPress() {
-		await Share.share({
-			message: `${this.state.note.title}\n\n${this.state.note.body}`,
-			title: this.state.note.title,
-		});
+		const shareText = `${this.state.note.title}\n\n${this.state.note.body}`;
+		const filename = this.state.note.id ?? uuid.create();
+
+		if (shareText.length > 100000) {
+			let fileToShare;
+			try {
+				// Using a .txt file extension causes a "No valid provider found from URL" error
+				// and blank share sheet on iOS for larger log files (around 200 KiB).
+				fileToShare = await writeTextToCacheFile(shareText, `${filename}.md`);
+				await shareFile(fileToShare, 'text/plain');
+			} catch (e) {
+				logger.error('Unable to share note data:', e);
+
+				// Display a message to the user (e.g. in the case where the user is out of disk space).
+				void shim.showErrorDialog(_('Unable to share note data. Reason: %s', e.toString()));
+			} finally {
+				if (fileToShare) {
+					await shim.fsDriver().remove(fileToShare);
+				}
+			}
+		} else {
+			// A txt extension is automatically appended to the title when shared to a file via this route
+			await Share.share({
+				message: shareText,
+				title: filename,
+			});
+		}
 	}
 
 	private properties_onPress() {
@@ -1172,69 +1254,6 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		await CommandService.instance().execute('attachFile', filePath);
 	};
 
-	// private vosk_:Vosk;
-
-	// private async getVosk() {
-	// 	if (this.vosk_) return this.vosk_;
-	// 	this.vosk_ = new Vosk();
-	// 	await this.vosk_.loadModel('model-fr-fr');
-	// 	return this.vosk_;
-	// }
-
-	// private async voiceRecording_onPress() {
-	// 	logger.info('Vosk: Getting instance...');
-
-	// 	const vosk = await this.getVosk();
-
-	// 	this.voskResult_ = [];
-
-	// 	const eventHandlers: any[] = [];
-
-	// 	eventHandlers.push(vosk.onResult(e => {
-	// 		logger.info('Vosk: result', e.data);
-	// 		this.voskResult_.push(e.data);
-	// 	}));
-
-	// 	eventHandlers.push(vosk.onError(e => {
-	// 		logger.warn('Vosk: error', e.data);
-	// 	}));
-
-	// 	eventHandlers.push(vosk.onTimeout(e => {
-	// 		logger.warn('Vosk: timeout', e.data);
-	// 	}));
-
-	// 	eventHandlers.push(vosk.onFinalResult(e => {
-	// 		logger.info('Vosk: final result', e.data);
-	// 	}));
-
-	// 	logger.info('Vosk: Starting recording...');
-
-	// 	void vosk.start();
-
-	// 	const buttonId = await dialogs.pop(this, 'Voice recording in progress...', [
-	// 		{ text: 'Stop recording', id: 'stop' },
-	// 		{ text: _('Cancel'), id: 'cancel' },
-	// 	]);
-
-	// 	logger.info('Vosk: Stopping recording...');
-	// 	vosk.stop();
-
-	// 	for (const eventHandler of eventHandlers) {
-	// 		eventHandler.remove();
-	// 	}
-
-	// 	logger.info('Vosk: Recording stopped:', this.voskResult_);
-
-	// 	if (buttonId === 'cancel') return;
-
-	// 	const newNote: NoteEntity = { ...this.state.note };
-	// 	newNote.body = `${newNote.body} ${this.voskResult_.join(' ')}`;
-	// 	this.setState({ note: newNote });
-	// 	this.scheduleSave();
-	// }
-
-
-
 	public menuOptions() {
 		const note = this.state.note;
 		const isTodo = note && !!note.is_todo;
@@ -1296,8 +1315,7 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 			});
 		}
 
-		const voiceTypingSupported = Platform.OS === 'android';
-		if (voiceTypingSupported) {
+		if (VoiceTyping.supported()) {
 			output.push({
 				title: _('Voice typing...'),
 				onPress: () => {
@@ -1492,10 +1510,16 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		return this.folderPickerOptions_;
 	}
 
-	private onBodyViewerScroll = (scrollTop: number) => {
-		this.lastBodyScroll = scrollTop;
+	private onBodyViewerScroll = (event: ScrollEventSlice) => {
+		this.lastBodyScroll = event.fraction;
+
+		NotePositionService.instance().updateScrollPosition(
+			this.props.noteId, defaultWindowId, event.fraction,
+		);
 	};
 
+	private onMarkdownEditorScroll = () => {};
+
 	public onBodyViewerCheckboxChange(newBody: string) {
 		void this.saveOneProperty('body', newBody);
 	}
@@ -1585,6 +1609,14 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 		// Currently keyword highlighting is supported only when FTS is available.
 		const keywords = this.props.searchQuery && !!this.props.ftsEnabled ? this.props.highlightedWords : emptyArray;
 
+		const increaseSpaceForEditor = this.props.lowVerticalSpace
+			&& this.state.mode === 'edit'
+			// For now, only dismiss other UI when search is visible. This provides a way to re-show the hidden UI (by dismissing search).
+			&& this.state.searchVisible
+			// Tapping on the title input when search is visible should edit the title, even if showing the keyboard decreases the
+			// available space.
+			&& !this.titleTextFieldRef.current?.isFocused();
+
 		let bodyComponent = null;
 
 		if (editorView) {
@@ -1609,7 +1641,7 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 							onMarkForDownload={this.onMarkForDownload}
 							onRequestEditResource={this.onEditResource}
 							onScroll={this.onBodyViewerScroll}
-							initialScroll={this.lastBodyScroll}
+							initialScrollPercent={this.lastBodyScroll}
 						/>
 					);
 			} else {
@@ -1654,7 +1686,7 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 
 					bodyComponent = <NoteEditor
 						ref={this.editorRef}
-						toolbarEnabled={this.props.toolbarEnabled}
+						toolbarEnabled={this.props.toolbarEnabled && !increaseSpaceForEditor}
 						themeId={this.props.themeId}
 						noteId={this.props.noteId}
 						noteHash={this.props.noteHash}
@@ -1663,8 +1695,9 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 						markupLanguage={this.state.note.markup_language}
 						globalSearch={this.props.searchQuery}
 						onChange={this.onMarkdownEditorTextChange}
-						onSelectionChange={this.onMarkdownEditorSelectionChange}
+						onSelectionChange={this.onEditorSelectionChange}
 						onUndoRedoDepthChange={this.onUndoRedoDepthChange}
+						onSearchVisibleChange={this.onSearchVisibleChange_}
 						onAttach={this.onAttach}
 						noteResources={this.state.noteResources}
 						readOnly={this.state.readOnly}
@@ -1676,6 +1709,14 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 							paddingLeft: 0,
 							paddingRight: 0,
 						}}
+
+						// For now, only save/restore the scroll location for the Rich Text editor since that editor's
+						// scroll should roughly match the viewer. In the future, it may make sense to refactor this to
+						// use mapsToLine (similar to what's done on desktop) to sync the Markdown editor scroll, but this
+						// will require refactoring.
+						initialScroll={this.props.editorType === EditorType.RichText ? this.lastBodyScroll : undefined}
+						onScroll={this.props.editorType === EditorType.RichText ? this.onBodyViewerScroll : this.onMarkdownEditorScroll}
+
 						mode={this.props.editorType}
 					/>;
 				}
@@ -1711,10 +1752,20 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 
 		const dueDate = Note.dueDateObject(note);
 
+		const titleToggleButton = Platform.OS === 'web' ? null :
+			<IconButton
+				icon={(!this.state.multiline && 'menu-down') || (this.state.multiline && 'menu-up')}
+				accessibilityLabel={(!this.state.multiline && _('Expand title')) || (this.state.multiline && _('Collapse title'))}
+				onPress={() => this.setState({ multiline: !this.state.multiline })}
+				size={30}
+				style={{ width: 30, height: 30, alignSelf: 'center' }}
+			/>;
+
 		const titleComp = (
 			<View style={titleContainerStyle}>
 				{isTodo && <Checkbox style={this.styles().checkbox} checked={!!Number(note.todo_completed)} onChange={this.todoCheckbox_change} />}
 				<TextInput
+					key={this.state.multiline ? 'multiLine' : 'singleLine'}
 					ref={this.titleTextFieldRef}
 					underlineColorAndroid="#ffffff00"
 					autoCapitalize="sentences"
@@ -1726,7 +1777,10 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 					placeholder={_('Add title')}
 					placeholderTextColor={theme.colorFaded}
 					editable={!this.state.readOnly}
+					multiline={this.state.multiline}
+					submitBehavior = "blurAndSubmit"
 				/>
+				{ titleToggleButton }
 			</View>
 		);
 
@@ -1754,25 +1808,27 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 
 		const { editorPlugin: activeEditorPlugin } = getActivePluginEditorView(this.props.plugins, this.props.windowId);
 
+		const header = <ScreenHeader
+			folderPickerOptions={this.folderPickerOptions()}
+			menuOptions={this.menuOptions()}
+			showSaveButton={showSaveButton}
+			saveButtonDisabled={saveButtonDisabled}
+			onSaveButtonPress={this.saveNoteButton_press}
+			showSideMenuButton={false}
+			showSearchButton={false}
+			showUndoButton={(this.state.undoRedoButtonState.canUndo || this.state.undoRedoButtonState.canRedo) && this.state.mode === 'edit'}
+			showRedoButton={this.state.undoRedoButtonState.canRedo && this.state.mode === 'edit'}
+			showPluginEditorButton={!!activeEditorPlugin}
+			undoButtonDisabled={!this.state.undoRedoButtonState.canUndo && this.state.undoRedoButtonState.canRedo}
+			onUndoButtonPress={this.screenHeader_undoButtonPress}
+			onRedoButtonPress={this.screenHeader_redoButtonPress}
+			title={getDisplayParentTitle(this.state.note, this.state.folder)}
+		/>;
+
 		return (
 			<View style={this.rootStyle(this.props.themeId).root}>
-				<ScreenHeader
-					folderPickerOptions={this.folderPickerOptions()}
-					menuOptions={this.menuOptions()}
-					showSaveButton={showSaveButton}
-					saveButtonDisabled={saveButtonDisabled}
-					onSaveButtonPress={this.saveNoteButton_press}
-					showSideMenuButton={false}
-					showSearchButton={false}
-					showUndoButton={(this.state.undoRedoButtonState.canUndo || this.state.undoRedoButtonState.canRedo) && this.state.mode === 'edit'}
-					showRedoButton={this.state.undoRedoButtonState.canRedo && this.state.mode === 'edit'}
-					showPluginEditorButton={!!activeEditorPlugin}
-					undoButtonDisabled={!this.state.undoRedoButtonState.canUndo && this.state.undoRedoButtonState.canRedo}
-					onUndoButtonPress={this.screenHeader_undoButtonPress}
-					onRedoButtonPress={this.screenHeader_redoButtonPress}
-					title={getDisplayParentTitle(this.state.note, this.state.folder)}
-				/>
-				{titleComp}
+				{!increaseSpaceForEditor && header}
+				{!increaseSpaceForEditor && titleComp}
 				{bodyComponent}
 				{renderVoiceTypingDialogs()}
 				{renderActionButton()}
@@ -1790,6 +1846,17 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 	}
 }
 
+const useHasLowAvailableSpace = () => {
+	const windowDimensions = useWindowDimensions();
+	const keyboardState = useKeyboardState();
+	const verticalSpaceAvailable = windowDimensions.height - keyboardState.dockedKeyboardHeight;
+
+	const lowVerticalScreenSpace = verticalSpaceAvailable < 270;
+	// Debounce state updates to avoid multiple re-renders when the keyboard is hidden, then quickly
+	// re-shown (e.g. when moving focus between text inputs).
+	return useDebounced(lowVerticalScreenSpace, Second / 10);
+};
+
 // We added this change to reset the component state when the props.noteId is changed.
 // NoteScreenComponent original implementation assumed that noteId would never change,
 // which can cause some bugs where previously set state to another note would interfere
@@ -1797,9 +1864,16 @@ class NoteScreenComponent extends BaseScreenComponent<ComponentProps, State> imp
 const NoteScreenWrapper = (props: Props) => {
 	const dialogs = useContext(DialogContext);
 	const visibleEditorPluginIds = useVisiblePluginEditorViewIds(props.plugins, props.windowId);
+	const lowVerticalSpace = useHasLowAvailableSpace();
 
 	return (
-		<NoteScreenComponent key={props.noteId} dialogs={dialogs} visibleEditorPluginIds={visibleEditorPluginIds} {...props} />
+		<NoteScreenComponent
+			key={props.noteId}
+			dialogs={dialogs}
+			visibleEditorPluginIds={visibleEditorPluginIds}
+			lowVerticalSpace={lowVerticalSpace}
+			{...props}
+		/>
 	);
 };
 
