@@ -1,7 +1,7 @@
 import { CommandRuntime, CommandDeclaration, CommandContext } from '@joplin/lib/services/CommandService';
 import { _ } from '@joplin/lib/locale';
 import { CommandRuntimeProps } from '../types';
-import time from '@joplin/lib/time';
+import { formatMsToLocal } from '@joplin/utils/time';
 
 export const declaration: CommandDeclaration = {
 	name: 'insertDateTime',
@@ -12,7 +12,7 @@ export const declaration: CommandDeclaration = {
 export const runtime = (props: CommandRuntimeProps): CommandRuntime => {
 	return {
 		execute: async (_context: CommandContext) => {
-			props.insertText(time.formatDateToLocal(new Date()));
+			props.insertText(formatMsToLocal(Date.now()));
 		},
 
 		enabledCondition: '!noteIsReadOnly',
