@@ -19,13 +19,13 @@ const afterFullPageRender = (
 			}
 
 			const hash = renderSettings.noteHash;
-			const initialScroll = renderSettings.initialScroll;
+			const initialScrollPercent = renderSettings.initialScrollPercent;
 
 			// Don't scroll to a hash if we're given initial scroll (initial scroll
 			// overrides scrolling to a hash).
-			if ((initialScroll ?? null) !== null) {
+			if ((initialScrollPercent ?? null) !== null) {
 				const scrollingElement = document.scrollingElement ?? document.documentElement;
-				scrollingElement.scrollTop = initialScroll;
+				scrollingElement.scrollTop = initialScrollPercent * scrollingElement.scrollHeight;
 			} else if (hash) {
 				// Gives it a bit of time before scrolling to the anchor
 				// so that images are loaded.
