@@ -12,11 +12,12 @@ import RNToWebViewMessenger from '../../utils/ipc/RNToWebViewMessenger';
 import useEditPopup from './utils/useEditPopup';
 import { PluginStates } from '@joplin/lib/services/plugins/reducer';
 import { RenderSettings } from './contentScript/Renderer';
-import resolvePathWithinDir from '@joplin/lib/utils/resolvePathWithinDir';
 import Resource from '@joplin/lib/models/Resource';
 import { ResourceInfos } from '@joplin/renderer/types';
 import useContentScripts from './utils/useContentScripts';
 import uuid from '@joplin/lib/uuid';
+import AsyncActionQueue from '@joplin/lib/AsyncActionQueue';
+import resolvePathWithinDir from '@joplin/lib/utils/resolvePathWithinDir';
 
 const logger = Logger.create('renderer/useWebViewSetup');
 
@@ -90,8 +91,8 @@ const useMessenger = (props: UseMessengerProps) => {
 
 	const messenger = useMemo(() => {
 		const fsDriver = shim.fsDriver();
-		const localApi = {
-			onScroll: (fraction: number) => onScrollRef.current?.(fraction),
+		const localApi: MainProcessApi = {
+			onScroll: (event) => onScrollRef.current?.(event),
 			onPostMessage: (message: string) => onPostMessageRef.current?.(message),
 			onPostPluginMessage,
 			fsDriver: {
@@ -136,7 +137,11 @@ const useTempDirPath = () => {
 	return tempDirPath;
 };
 
-const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
+type Result = SetUpResult<RendererControl> & {
+	hasPluginScripts: boolean;
+};
+
+const useWebViewSetup = (props: Props): Result => {
 	const tempDirPath = useTempDirPath();
 	const { css, injectedJs } = useSource(tempDirPath);
 	const { editPopupCss, createEditPopupSyntax, destroyEditPopupSyntax } = useEditPopup(props.themeId);
@@ -149,6 +154,8 @@ const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
 		void messenger.remoteApi.renderer.setExtraContentScriptsAndRerender(contentScripts);
 	}, [messenger, contentScripts]);
 
+	const onRerenderRequestRef = useRef(()=>{});
+
 	const rendererControl = useMemo((): RendererControl => {
 		const renderer = messenger.remoteApi.renderer;
 
@@ -185,7 +192,7 @@ const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
 			};
 
 			let settingsChanged = false;
-			const settings: RenderSettings = {
+			const getSettings = (): RenderSettings => ({
 				...options,
 				codeTheme: theme.codeThemeCss,
 				// We .stringify the theme to avoid a JSON serialization error involving
@@ -201,31 +208,47 @@ const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
 					const key = `${pluginId}.${settingKey}`;
 					if (!pluginSettingKeysRef.current.has(key)) {
 						pluginSettingKeysRef.current.add(key);
+						onRerenderRequestRef.current();
 						settingsChanged = true;
 					}
 				},
-				readAssetBlob: (assetPath: string): Promise<Blob> => {
-					// Built-in assets are in resourceDir, external plugin assets are in cacheDir.
-					const assetsDirs = [Setting.value('resourceDir'), Setting.value('cacheDir')];
+				// Handles plugin asset loading on web (where the WebView can't load assets directly).
+				readAssetBlob: async (assetPath: string): Promise<Blob> => {
+					if (assetPath.startsWith('pluginAssets/')) { // Built-in plugin asset
+						assetPath = assetPath.replace(/^pluginAssets\//, '');
 
-					let resolvedPath = null;
-					for (const assetDir of assetsDirs) {
-						resolvedPath ??= resolvePathWithinDir(assetDir, assetPath);
-						if (resolvedPath) break;
-					}
+						const fullPath = shim.fsDriver().resolveRelativePathWithinDir(
+							Setting.value('pluginAssetDir'), assetPath,
+						);
+						return shim.fsDriver().fileAtPath(fullPath);
+					} else { // Asset from an installed/development plugin
+						// User-installed plugins are stored in cacheDir
+						const allowedBasePaths = [Setting.value('cacheDir')];
+						// Development plugins are stored in other locations. Add them separately:
+						if (Setting.value('plugins.devPluginPaths')) {
+							allowedBasePaths.push(...Setting.value('plugins.devPluginPaths').split(','));
+						}
 
-					if (!resolvedPath) {
-						throw new Error(`Failed to load asset at ${assetPath} -- not in any of the allowed asset directories: ${assetsDirs.join(',')}.`);
+						for (const basePath of allowedBasePaths) {
+							const resolved = resolvePathWithinDir(basePath, assetPath);
+							if (resolved) {
+								return shim.fsDriver().fileAtPath(resolved);
+							}
+						}
+
+						throw new Error(`Unable to resolve plugin asset: ${assetPath}`);
 					}
-					return shim.fsDriver().fileAtPath(resolvedPath);
 				},
 				removeUnusedPluginAssets: options.removeUnusedPluginAssets,
-			};
+				globalSettings: {
+					'markdown.plugin.abc.options': Setting.value('markdown.plugin.abc.options'),
+				},
+			});
 
 			await transferResources(options.resources);
 
 			return {
-				settings,
+				getSettings,
 				getSettingsChanged() {
 					return settingsChanged;
 				},
@@ -234,23 +257,28 @@ const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
 
 		return {
 			rerenderToBody: async (markup, options, cancelEvent) => {
-				const { settings, getSettingsChanged } = await prepareRenderer(options);
+				const { getSettings } = await prepareRenderer(options);
 				if (cancelEvent?.cancelled) return null;
 
-				const output = await renderer.rerenderToBody(markup, settings);
-				if (cancelEvent?.cancelled) return null;
+				const render = async () => {
+					if (cancelEvent?.cancelled) return;
 
-				if (getSettingsChanged()) {
-					return await renderer.rerenderToBody(markup, settings);
-				}
-				return output;
+					await renderer.rerenderToBody(markup, getSettings());
+				};
+
+				const queue = new AsyncActionQueue();
+				onRerenderRequestRef.current = async () => {
+					queue.push(render);
+				};
+
+				return await render();
 			},
 			render: async (markup, options) => {
-				const { settings, getSettingsChanged } = await prepareRenderer(options);
-				const output = await renderer.render(markup, settings);
+				const { getSettings, getSettingsChanged } = await prepareRenderer(options);
+				const output = await renderer.render(markup, getSettings());
 
 				if (getSettingsChanged()) {
-					return await renderer.render(markup, settings);
+					return await renderer.render(markup, getSettings());
 				}
 				return output;
 			},
@@ -260,6 +288,7 @@ const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
 		};
 	}, [createEditPopupSyntax, destroyEditPopupSyntax, messenger]);
 
+	const hasPluginScripts = contentScripts.length > 0;
 	return useMemo(() => {
 		return {
 			api: rendererControl,
@@ -271,8 +300,9 @@ const useWebViewSetup = (props: Props): SetUpResult<RendererControl> => {
 				onLoadEnd: messenger.onWebViewLoaded,
 				onMessage: messenger.onWebViewMessage,
 			},
+			hasPluginScripts,
 		};
-	}, [css, injectedJs, messenger, editPopupCss, rendererControl]);
+	}, [css, injectedJs, messenger, editPopupCss, rendererControl, hasPluginScripts]);
 };
 
 export default useWebViewSetup;
