@@ -1,4 +1,8 @@
+const baseConfig = require('../../jest.config.base.js');
+
 module.exports = {
+	...baseConfig,
+
 	preset: 'react-native',
 
 	'moduleFileExtensions': [
