@@ -1,5 +1,6 @@
 import { EditorView } from '@codemirror/view';
 import { Prec } from '@codemirror/state';
+import { editorSettingsFacet } from './editorSettingsExtension';
 
 const hasMultipleCursors = (view: EditorView) => {
 	return view.state.selection.ranges.length > 1;
@@ -12,7 +13,9 @@ const ctrlClickActionExtension = (onCtrlClick: OnCtrlClick) => {
 		Prec.high([
 			EditorView.domEventHandlers({
 				mousedown: (event: MouseEvent, view: EditorView) => {
-					const hasModifier = event.ctrlKey || event.metaKey;
+					const editorSettings = view.state.facet(editorSettingsFacet);
+					const hasModifier = editorSettings.preferMacShortcuts ? event.metaKey : event.ctrlKey;
+
 					// The default CodeMirror action for ctrl-click is to add another cursor
 					// to the document. If the user already has multiple cursors, assume that
 					// the ctrl-click action is intended to add another.
