@@ -1,22 +1,19 @@
 import addFormattingClasses from './addFormattingClasses';
-import renderBlockImages from './renderBlockImages';
+import replaceBackslashEscapes from './replaceBackslashEscapes';
 import replaceBulletLists from './replaceBulletLists';
 import replaceCheckboxes from './replaceCheckboxes';
 import replaceDividers from './replaceDividers';
 import replaceFormatCharacters from './replaceFormatCharacters';
-import { RenderedContentContext } from './types';
+import replaceInlineHtml from './replaceInlineHtml';
 
-interface Options {
-	renderImages: boolean;
-}
-
-export default (context: RenderedContentContext, options: Options) => {
+export default () => {
 	return [
 		replaceCheckboxes,
 		replaceBulletLists,
 		replaceFormatCharacters,
+		replaceBackslashEscapes,
 		replaceDividers,
 		addFormattingClasses,
-		...(options.renderImages ? [renderBlockImages(context)] : []),
+		replaceInlineHtml,
 	];
 };
