@@ -3,20 +3,31 @@ import { SyntaxNodeRef } from '@lezer/common';
 import makeReplaceExtension from './utils/makeInlineReplaceExtension';
 import toggleCheckboxAt from '../../utils/markdown/toggleCheckboxAt';
 
-const checkboxClassName = 'cm-ext-checkbox-toggle';
+const checkboxContainerClassName = 'cm-ext-checkbox-toggle';
+const checkboxClassName = 'cm-ext-checkbox';
 
 
 class CheckboxWidget extends WidgetType {
-	public constructor(private checked: boolean, private depth: number, private label: string) {
+	public constructor(
+		private checked: boolean,
+		private depth: number,
+		private label: string,
+		private markup: string,
+	) {
 		super();
 	}
 
 	public eq(other: CheckboxWidget) {
-		return other.checked === this.checked && other.depth === this.depth && other.label === this.label;
+		return other.checked === this.checked
+			&& other.depth === this.depth
+			&& other.label === this.label
+			&& other.markup === this.markup;
 	}
 
 	private applyContainerClasses(container: HTMLElement) {
-		container.classList.add(checkboxClassName);
+		container.classList.add(checkboxContainerClassName);
+		// For sizing: Should have the same font/styles as non-rendered checkboxes:
+		container.classList.add('cm-taskMarker');
 
 		for (const className of [...container.classList]) {
 			if (className.startsWith('-depth-')) {
@@ -30,12 +41,22 @@ class CheckboxWidget extends WidgetType {
 	public toDOM(view: EditorView) {
 		const container = document.createElement('span');
 
+		const sizingNode = document.createElement('span');
+		sizingNode.classList.add('sizing');
+		sizingNode.textContent = this.markup;
+		container.appendChild(sizingNode);
+
+		const checkboxWrapper = document.createElement('span');
+		checkboxWrapper.classList.add('content');
+		container.appendChild(checkboxWrapper);
+
 		const checkbox = document.createElement('input');
 		checkbox.type = 'checkbox';
 		checkbox.checked = this.checked;
 		checkbox.ariaLabel = this.label;
 		checkbox.title = this.label;
-		container.appendChild(checkbox);
+		checkbox.classList.add(checkboxClassName);
+		checkboxWrapper.appendChild(checkbox);
 
 		checkbox.oninput = () => {
 			toggleCheckboxAt(view.posAtDOM(container))(view);
@@ -66,16 +87,32 @@ const completedListItemDecoration = Decoration.line({ class: completedTaskClassN
 
 const replaceCheckboxes = [
 	EditorView.theme({
+		[`& .${checkboxContainerClassName}`]: {
+			position: 'relative',
+
+			'& > .sizing': {
+				visibility: 'hidden',
+			},
+
+			'& > .content': {
+				position: 'absolute',
+				left: '0',
+				right: '0',
+				top: '0',
+				bottom: '0',
+				textAlign: 'center',
+			},
+		},
 		[`& .${checkboxClassName}`]: {
-			'& > input': {
-				width: '1.1em',
-				height: '1.1em',
-				margin: '4px',
-				verticalAlign: 'middle',
-			},
-			'&:not(.-depth-1) > input': {
-				marginInlineStart: 0,
-			},
+			verticalAlign: 'middle',
+
+			// Ensure that the checkbox grows as the font size increases:
+			width: '100%',
+			minHeight: '70%',
+
+			// Shift the checkbox slightly so that it's aligned with the list item bullet point
+			margin: '0',
+			marginBottom: '3px',
 		},
 		[`& .${completedTaskClassName}`]: {
 			opacity: 0.69,
@@ -84,7 +121,7 @@ const replaceCheckboxes = [
 	EditorView.domEventHandlers({
 		mousedown: (event) => {
 			const target = event.target as Element;
-			if (target.nodeName === 'INPUT' && target.parentElement?.classList?.contains(checkboxClassName)) {
+			if (target.nodeName === 'INPUT' && target.classList?.contains(checkboxClassName)) {
 				// Let the checkbox handle the event
 				return true;
 			}
@@ -101,8 +138,14 @@ const replaceCheckboxes = [
 			if (node.name === 'TaskMarker') {
 				const containerLine = state.doc.lineAt(node.from);
 				const labelText = state.doc.sliceString(node.to, containerLine.to);
+				const markerText = state.doc.sliceString(node.from, node.to);
 
-				return new CheckboxWidget(markerIsChecked(node), parentTags.get('ListItem') ?? 0, labelText);
+				return new CheckboxWidget(
+					markerIsChecked(node),
+					parentTags.get('ListItem') ?? 0,
+					labelText,
+					markerText,
+				);
 			} else if (node.name === 'Task') {
 				const marker = node.node.getChild('TaskMarker');
 				if (marker && markerIsChecked(marker)) {
@@ -119,7 +162,7 @@ const replaceCheckboxes = [
 					return null;
 				}
 
-				return [listMarker.from, node.to];
+				return [node.from, node.to];
 			} else if (node.name === 'Task') {
 				const taskLine = state.doc.lineAt(node.from);
 				return [taskLine.from];
