@@ -7,7 +7,7 @@ interface MarkupToHtmlOptions {
 }
 
 export type MarkupToHtml = (markup: string, options: MarkupToHtmlOptions)=> Promise<RenderResult>;
-export type HtmlToMarkup = (html: Node|DocumentFragment)=> string;
+export type HtmlToMarkup = (html: HTMLElement)=> string;
 
 export interface RendererControl {
 	renderMarkupToHtml: MarkupToHtml;
@@ -18,6 +18,7 @@ export interface CodeEditorControl {
 	focus: ()=> void;
 	remove: ()=> void;
 	updateBody: (newValue: string)=> void;
+	select: (from: number, to: number)=> void;
 }
 export type OnCodeEditorChange = (newValue: string)=> void;
 
