@@ -14,8 +14,10 @@ const createEditorSettings = (themeId: number) => {
 		autocompleteMarkup: true,
 		tabMovesFocus: false,
 		inlineRenderingEnabled: true,
+		highlightActiveLine: false,
 
 		keymap: EditorKeymap.Default,
+		preferMacShortcuts: false,
 		language: EditorLanguageType.Markdown,
 		themeData,
 
