@@ -1,4 +1,4 @@
-import { setupDatabaseAndSynchronizer, switchClient, createFolderTree, supportDir, msleep, resourceService } from '../testing/test-utils';
+import { setupDatabaseAndSynchronizer, switchClient, createFolderTree, supportDir, msleep, resourceService, simulateReadOnlyShareEnv } from '../testing/test-utils';
 import Folder from '../models/Folder';
 import { allNotesFolders } from '../testing/test-utils-synchronizer';
 import Note from '../models/Note';
@@ -181,6 +181,21 @@ describe('models/Folder.sharing', () => {
 		}
 	}));
 
+	it('should not fail to update share IDs when an outdated share ID is contained in a read-only folder', async () => {
+		const shareId = 'abcd1234';
+		const root = await Folder.save({ title: 'read-only', share_id: shareId });
+		// Save a child with a different share ID
+		const child = await Note.save({ title: 'Test', parent_id: root.id, share_id: `${shareId}-different` });
+
+		const reset = simulateReadOnlyShareEnv([shareId]);
+		try {
+			await Folder.updateAllShareIds(resourceService(), []);
+			expect(await Note.load(child.id)).toMatchObject({ share_id: shareId });
+		} finally {
+			reset();
+		}
+	});
+
 	it('should unshare a subfolder of a shared folder when it is moved to the root', (async () => {
 		let folder1 = await createFolderTree('', [
 			{
@@ -505,7 +520,7 @@ describe('models/Folder.sharing', () => {
 		expect(note4.user_updated_time).toBe(userUpdatedTimes[note4.id]);
 	});
 
-	it('should unshare items that are no longer part of an existing share', async () => {
+	it('should clear share_ids for items that are no longer part of an existing share', async () => {
 		await createFolderTree('', [
 			{
 				title: 'folder 1',
@@ -591,4 +606,34 @@ describe('models/Folder.sharing', () => {
 		}
 	});
 
+	it('should not change the updated_time when clearing share_ids for no-longer-shared items', async () => {
+		await createFolderTree('', [
+			{
+				title: 'folder 1',
+				share_id: '1',
+				children: [
+					{
+						title: 'note 1',
+					},
+				],
+			},
+		]);
+
+		await Folder.updateAllShareIds(resourceService(), []);
+
+		const folder1 = await Folder.loadByTitle('folder 1');
+		const note1 = await Note.loadByTitle('note 1');
+		await Folder.updateNoLongerSharedItems([]);
+
+		// To avoid conflicts, should not change the updated_time
+		expect(await Note.loadByTitle('note 1')).toMatchObject({
+			updated_time: note1.updated_time,
+			share_id: '',
+		});
+		expect(await Folder.loadByTitle('folder 1')).toMatchObject({
+			updated_time: folder1.updated_time,
+			share_id: '',
+		});
+	});
+
 });
