@@ -125,7 +125,7 @@ describe('services_KeymapService', () => {
 			expect(keymapService.getAccelerator('textBold')).toEqual('Ctrl+B');
 		});
 
-		if ('should throw when an invalid command is requested', () => {
+		it('should throw when an invalid command is requested', () => {
 			expect(() => keymapService.getAccelerator('totallyNonExistentCommand')).toThrow();
 		});
 	});
