@@ -1,6 +1,8 @@
 import BaseModel from '../BaseModel';
 import Note from '../models/Note';
 import Resource from '../models/Resource';
+import ResourceLocalState from '../models/ResourceLocalState';
+import { ResourceEntity } from '../services/database/types';
 
 // eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
 let resourceCache_: any = {};
@@ -9,8 +11,15 @@ export function clearResourceCache() {
 	resourceCache_ = {};
 }
 
-// eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
-export default async function attachedResources(noteBody: string): Promise<any> {
+interface AttachedResource {
+	item: ResourceEntity;
+	localState: ResourceLocalState;
+}
+export interface AttachedResources {
+	[id: string]: AttachedResource;
+}
+
+export default async function attachedResources(noteBody: string): Promise<AttachedResources> {
 	if (!noteBody) return {};
 	const resourceIds = await Note.linkedItemIdsByType(BaseModel.TYPE_RESOURCE, noteBody);
 
