@@ -5,10 +5,8 @@ export function cookieSet(ctx: AppContext, name: string, value: string) {
 	ctx.cookies.set(name, value, {
 		// Means that the cookies cannot be accessed from JavaScript
 		httpOnly: true,
-		// Can only be transferred over https
 		secure: config().cookieSecure,
-		// Prevent cookies from being sent in cross-site requests
-		sameSite: true,
+		sameSite: config().cookieSameSite,
 	});
 }
 
