@@ -1,17 +1,52 @@
 import { strict as assert } from 'assert';
 import { ActionableClient, FolderData, FuzzContext, ItemId, NoteData, ShareOptions, TreeItem, assertIsFolder, isFolder } from './types';
-import type Client from './Client';
 import FolderRecord from './model/FolderRecord';
 
 interface ClientData {
 	childIds: ItemId[];
 }
 
+interface ClientInfo {
+	email: string;
+}
+
+interface ActionLogEntry {
+	action: string;
+	source: string;
+}
+
 class ActionTracker {
+	private idToActionLog_: Map<ItemId, ActionLogEntry[]> = new Map();
 	private idToItem_: Map<ItemId, TreeItem> = new Map();
 	private tree_: Map<string, ClientData> = new Map();
 	public constructor(private readonly context_: FuzzContext) {}
 
+	public getActionLog(id: ItemId) {
+		return [...(this.idToActionLog_.get(id) ?? [])];
+	}
+
+	public printActionLog(id: ItemId) {
+		const logEntries = this.getActionLog(id);
+		if (logEntries.length === 0) {
+			process.stdout.write('N/A\n');
+			return;
+		}
+
+		const log = logEntries
+			.map(item => `in:${item.source}: ${item.action}`)
+			.join('\n');
+		process.stdout.write(`${log}\n`);
+	}
+
+	private logAction_(item: ItemId|TreeItem, action: string, source: string) {
+		const itemId = typeof item === 'string' ? item : item.id;
+
+		const log = this.idToActionLog_.get(itemId) ?? [];
+		this.idToActionLog_.set(itemId, log);
+
+		log.push({ action, source });
+	}
+
 	private getToplevelParent_(item: ItemId|TreeItem) {
 		let itemId = typeof item === 'string' ? item : item.id;
 		const originalItemId = itemId;
@@ -87,7 +122,7 @@ class ActionTracker {
 		}
 	}
 
-	public track(client: { email: string }) {
+	public track(client: ClientInfo) {
 		const clientId = client.email;
 		// If the client's remote account already exists, continue using it:
 		if (!this.tree_.has(clientId)) {
@@ -96,6 +131,14 @@ class ActionTracker {
 			});
 		}
 
+		const logAction = (item: ItemId|TreeItem, action: string) => {
+			this.logAction_(item, action, clientId);
+		};
+		const updateItem = (id: ItemId, newValue: TreeItem, changeLabel: string) => {
+			logAction(id, changeLabel);
+			this.idToItem_.set(id, newValue);
+		};
+
 		const getChildIds = (itemId: ItemId) => {
 			const item = this.idToItem_.get(itemId);
 			if (!item || !isFolder(item)) return [];
@@ -204,10 +247,12 @@ class ActionTracker {
 				}
 
 				this.idToItem_.delete(id);
+				logAction(id, 'removed');
 			} else {
 				const idIsUnused = removeRootItem(item.id);
 				if (idIsUnused) {
 					this.idToItem_.delete(id);
+					logAction(id, 'removed');
 				}
 			}
 
@@ -220,8 +265,9 @@ class ActionTracker {
 				}
 			}
 		};
-		const mapItems = <T> (map: (item: TreeItem)=> T) => {
-			const workList: ItemId[] = [...this.tree_.get(clientId).childIds];
+		const mapItems = <T> (map: (item: TreeItem)=> T, startFolder?: FolderRecord) => {
+			const startIds: readonly ItemId[] = (startFolder ?? this.tree_.get(clientId)).childIds;
+			const workList = [...startIds];
 			const result: T[] = [];
 
 			while (workList.length > 0) {
@@ -241,6 +287,8 @@ class ActionTracker {
 			return result;
 		};
 
+		const descendants = (folder: FolderRecord) => mapItems(item => item, folder);
+
 		const getAllFolders = () => {
 			return mapItems((item): FolderRecord => {
 				return isFolder(item) ? item : null;
@@ -271,15 +319,38 @@ class ActionTracker {
 			}
 		};
 
+		const removeFromShare = (id: ItemId, shareWith: ClientInfo) => {
+			const targetItem = this.idToItem_.get(id);
+			assertIsFolder(targetItem);
+
+			assert.ok(targetItem.isSharedWith(shareWith.email), `Folder ${id} should be shared with ${shareWith.email}`);
+
+			const otherSubTree = this.tree_.get(shareWith.email);
+			this.tree_.set(shareWith.email, {
+				...otherSubTree,
+				childIds: otherSubTree.childIds.filter(childId => childId !== id),
+			});
+
+			const updateLabel = `remove ${shareWith.email} from share`;
+			updateItem(
+				id, targetItem.withRemovedFromShare(shareWith.email), updateLabel,
+			);
+			for (const item of descendants(targetItem)) {
+				logAction(item, updateLabel);
+			}
+
+			this.checkRep_();
+		};
+
 		const tracker: ActionableClient = {
 			createNote: (data: NoteData) => {
 				assertWriteable(data.parentId);
 
 				assert.ok(!!data.parentId, `note ${data.id} should have a parentId`);
 				assert.ok(!this.idToItem_.has(data.id), `note ${data.id} should not yet exist`);
-				this.idToItem_.set(data.id, {
+				updateItem(data.id, {
 					...data,
-				});
+				}, 'created');
 				addChild(data.parentId, data.id);
 
 				this.checkRep_();
@@ -288,14 +359,26 @@ class ActionTracker {
 			updateNote: (data: NoteData) => {
 				assertWriteable(data.parentId);
 
-				const oldItem = this.idToItem_.get(data.id);
+				const oldItem = this.idToItem_.get(data.id) as NoteData;
 				assert.ok(oldItem, `note ${data.id} should exist`);
 				assert.ok(!!data.parentId, `note ${data.id} should have a parentId`);
 
+				// Additional debugging information about what changed:
+				const changedFieldsInfo = Object.entries(data)
+					.filter(([key, newValue]) => {
+						const itemKey = key as keyof NoteData;
+						// isShared is a virtual property
+						return key !== 'isShared'
+							&& oldItem[itemKey] !== newValue;
+					})
+					.map(([key]) => {
+						return key;
+					});
+
 				removeChild(oldItem.parentId, data.id);
-				this.idToItem_.set(data.id, {
+				updateItem(data.id, {
 					...data,
-				});
+				}, `updated (changed fields: ${JSON.stringify(changedFieldsInfo)})`);
 				addChild(data.parentId, data.id);
 
 				this.checkRep_();
@@ -305,13 +388,14 @@ class ActionTracker {
 				const parentId = data.parentId ?? '';
 				assertWriteable(parentId);
 
-				this.idToItem_.set(data.id, new FolderRecord({
+				updateItem(data.id, new FolderRecord({
 					...data,
 					parentId: parentId ?? '',
 					childIds: getChildIds(data.id),
 					sharedWith: [],
 					ownedByEmail: clientId,
-				}));
+					isShared: false,
+				}), 'created');
 				addChild(data.parentId, data.id);
 
 				this.checkRep_();
@@ -330,7 +414,22 @@ class ActionTracker {
 				this.checkRep_();
 				return Promise.resolve();
 			},
-			shareFolder: (id: ItemId, shareWith: Client, options: ShareOptions) => {
+			deleteNote: (id: ItemId) => {
+				this.checkRep_();
+
+				const item = this.idToItem_.get(id);
+				if (!item) throw new Error(`Not found ${id}`);
+				assert.ok(!isFolder(item), 'should be a note');
+				assertWriteable(item);
+
+				removeItemRecursive(id);
+
+				this.checkRep_();
+				return Promise.resolve();
+			},
+			shareFolder: (id: ItemId, shareWith: ClientInfo, options: ShareOptions) => {
+				assert.notEqual(client.email, shareWith.email, 'Cannot share a folder with the same client');
+
 				const itemToShare = this.idToItem_.get(id);
 				assertIsFolder(itemToShare);
 
@@ -347,26 +446,34 @@ class ActionTracker {
 					childIds: [...shareWithChildIds, id],
 				});
 
-				this.idToItem_.set(
-					id, itemToShare.withShared(shareWith.email, options.readOnly),
+				updateItem(
+					id,
+					itemToShare.withShared(shareWith.email, options.readOnly),
+					`shared with ${shareWith.email}`,
 				);
 
+				// Additional logging
+				for (const item of descendants(itemToShare)) {
+					logAction(item, `ancestor shared with ${shareWith.email}`);
+				}
+
 				this.checkRep_();
 				return Promise.resolve();
 			},
-			removeFromShare: (id: ItemId, shareWith: Client) => {
+			removeFromShare: (id, client) => Promise.resolve(removeFromShare(id, client)),
+			deleteAssociatedShare: (id: ItemId) => {
 				const targetItem = this.idToItem_.get(id);
 				assertIsFolder(targetItem);
 
-				assert.ok(targetItem.isSharedWith(shareWith.email), `Folder ${id} should be shared with ${shareWith.label}`);
+				for (const recipient of targetItem.shareRecipients) {
+					removeFromShare(id, { email: recipient });
+				}
 
-				const otherSubTree = this.tree_.get(shareWith.email);
-				this.tree_.set(shareWith.email, {
-					...otherSubTree,
-					childIds: otherSubTree.childIds.filter(childId => childId !== id),
-				});
+				updateItem(id, targetItem.withUnshared(), 'unshared');
 
-				this.idToItem_.set(id, targetItem.withUnshared(shareWith.email));
+				for (const item of descendants(targetItem)) {
+					logAction(item, 'parent share removed');
+				}
 
 				this.checkRep_();
 				return Promise.resolve();
@@ -395,14 +502,44 @@ class ActionTracker {
 
 				removeChild(item.parentId, itemId);
 				addChild(newParentId, itemId);
-				this.idToItem_.set(
+				updateItem(
 					itemId,
 					isFolder(item) ? item.withParent(newParentId) : { ...item, parentId: newParentId },
+					`moved to id:${newParentId}`,
 				);
 
 				this.checkRep_();
 				return Promise.resolve();
 			},
+			publishNote: (id) => {
+				const oldItem = this.idToItem_.get(id);
+				assert.ok(oldItem, 'should exist');
+				assert.ok(!isFolder(oldItem), 'folders cannot be published');
+				assert.ok(!oldItem.published, 'should not be published');
+
+
+				updateItem(id, {
+					...oldItem,
+					published: true,
+				}, 'published');
+
+				this.checkRep_();
+				return Promise.resolve();
+			},
+			unpublishNote: (id) => {
+				const oldItem = this.idToItem_.get(id);
+				assert.ok(oldItem, 'should exist');
+				assert.ok(!isFolder(oldItem), 'folders cannot be unpublished');
+				assert.ok(oldItem.published, 'should be published');
+
+				updateItem(id, {
+					...oldItem,
+					published: false,
+				}, 'unpublished');
+
+				this.checkRep_();
+				return Promise.resolve();
+			},
 			sync: () => Promise.resolve(),
 			listNotes: () => {
 				const notes = mapItems(item => {
@@ -458,14 +595,20 @@ class ActionTracker {
 					folders = folders.filter(folder => !isReadOnly(folder.id));
 				}
 
-				const folderIndex = this.context_.randInt(0, folders.length);
-				return folders.length ? folders[folderIndex] : null;
+				return folders.length ? this.context_.randomFrom(folders) : null;
 			},
 			randomNote: async () => {
 				const notes = await tracker.listNotes();
 				const noteIndex = this.context_.randInt(0, notes.length);
 				return notes.length ? notes[noteIndex] : null;
 			},
+			// Note: Does not verify that the current client has access to the item
+			itemById: (id: ItemId) => {
+				const item = this.idToItem_.get(id);
+
+				if (!item) throw new Error(`No item found with ID ${id}`);
+				return item;
+			},
 		};
 		return tracker;
 	}
