@@ -1,3 +1,4 @@
+import Logger from '@joplin/utils/Logger';
 import ActionTracker from './ActionTracker';
 import Client from './Client';
 import { CleanupTask, FuzzContext } from './types';
@@ -5,6 +6,8 @@ import { CleanupTask, FuzzContext } from './types';
 type AddCleanupTask = (task: CleanupTask)=> void;
 type ClientFilter = (client: Client)=> boolean;
 
+const logger = Logger.create('ClientPool');
+
 export default class ClientPool {
 	public static async create(
 		context: FuzzContext,
@@ -23,7 +26,7 @@ export default class ClientPool {
 
 		return new ClientPool(context, clientPool);
 	}
-	public constructor(
+	private constructor(
 		private readonly context_: FuzzContext,
 		private clients_: Client[],
 	) {
@@ -38,10 +41,32 @@ export default class ClientPool {
 		});
 	}
 
+	public async createRandomInitialItemsAndSync() {
+		for (const client of this.clients) {
+			logger.info('Creating items for ', client.email);
+			const actionCount = this.context_.randomFrom([0, 10, 100]);
+			await client.createOrUpdateMany(actionCount);
+
+			await client.sync();
+		}
+	}
+
 	public clientsByEmail(email: string) {
 		return this.clients.filter(client => client.email === email);
 	}
 
+	public clientById(id: number) {
+		const client = this.clients[id];
+		if (!client) throw new Error(`Not found: ${id}`);
+		return client;
+	}
+
+	public getClientId(client: Client): number {
+		const index = this.clients.indexOf(client);
+		if (index === -1) throw new Error(`Not found: ${client}`);
+		return index;
+	}
+
 	public randomClient(filter: ClientFilter = ()=>true) {
 		const clients = this.clients_.filter(filter);
 		return clients[
@@ -67,9 +92,12 @@ export default class ClientPool {
 	}
 
 	public async syncAll() {
-		for (const client of this.clients_) {
-			await client.sync();
-		}
+		// Sync all clients at roughly the same time. Some sync bugs are only apparent
+		// when multiple clients are syncing simultaneously.
+		await Promise.all(this.clients_.map(c => c.sync()));
+
+		// Note: For more deterministic behavior, sync clients individually instead:
+		//   for (const client of this.clients_) { await client.sync(); }
 	}
 
 	public get clients() {
