@@ -11,6 +11,7 @@ export interface NoteData {
 	id: ItemId;
 	title: string;
 	body: string;
+	published: boolean;
 }
 export interface DetailedNoteData extends NoteData {
 	isShared: boolean;
@@ -41,13 +42,22 @@ export const assertIsFolder: (item: TreeItem)=> asserts item is FolderRecord = i
 		throw new Error(`Expected item with ID ${item?.id} to be a folder.`);
 	}
 };
+export const assertIsNote: (item: TreeItem)=> asserts item is NoteData = item => {
+	if (!item) throw new Error(`Item ${item} is not a note`);
+	if (isFolder(item)) throw new Error(`Expected item with ID ${item?.id} to be a note.`);
+};
 
 export interface FuzzContext {
 	serverUrl: string;
 	isJoplinCloud: boolean;
+	keepAccounts: boolean;
+	enableE2ee: boolean;
 	baseDir: string;
+
 	execApi: (method: HttpMethod, route: string, debugAction: Json)=> Promise<Json>;
 	randInt: (low: number, high: number)=> number;
+	randomString: (targetLength: number)=> string;
+	randomFrom: <T> (data: T[])=> T;
 }
 
 export interface RandomFolderOptions {
@@ -67,10 +77,14 @@ export interface ActionableClient {
 	createFolder(data: FolderData): Promise<void>;
 	shareFolder(id: ItemId, shareWith: Client, options: ShareOptions): Promise<void>;
 	removeFromShare(id: string, shareWith: Client): Promise<void>;
+	deleteAssociatedShare(id: string): Promise<void>;
 	deleteFolder(id: ItemId): Promise<void>;
+	deleteNote(id: ItemId): Promise<void>;
 	createNote(data: NoteData): Promise<void>;
 	updateNote(data: NoteData): Promise<void>;
 	moveItem(itemId: ItemId, newParentId: ItemId): Promise<void>;
+	publishNote(id: ItemId): Promise<void>;
+	unpublishNote(id: ItemId): Promise<void>;
 	sync(): Promise<void>;
 
 	listNotes(): Promise<NoteData[]>;
@@ -78,6 +92,7 @@ export interface ActionableClient {
 	allFolderDescendants(parentId: ItemId): Promise<ItemId[]>;
 	randomFolder(options: RandomFolderOptions): Promise<FolderRecord>;
 	randomNote(options: RandomNoteOptions): Promise<NoteData>;
+	itemById(id: ItemId): TreeItem;
 }
 
 export interface UserData {
