@@ -1,6 +1,7 @@
 import { execCommand } from '@joplin/utils';
 import { copy, mkdirp, move, readFile, readFileSync, remove, stat, writeFile, writeFileSync } from 'fs-extra';
 import { execCommandVerbose, execCommandWithPipes, githubRelease, githubOauthToken, fileExists, gitPullTry, completeReleaseWithChangelog } from './tool-utils';
+import { homedir } from 'os';
 const path = require('path');
 const fetch = require('node-fetch');
 const uriTemplate = require('uri-template');
@@ -13,6 +14,7 @@ interface Release {
 	downloadUrl: string;
 	apkFilename: string;
 	apkFilePath: string;
+	publish: boolean;
 }
 
 type PatcherCallback = (content: string)=> Promise<string>;
@@ -58,8 +60,9 @@ class Patcher {
 
 interface ReleaseConfig {
 	name: string;
-	patch?: (patcher: Patcher, rnDir: string)=> Promise<void>;
+	patch?: (patcher: Patcher, rootDir: string)=> Promise<void>;
 	disabled?: boolean;
+	publish: boolean;
 }
 
 function increaseGradleVersionCode(content: string) {
@@ -100,7 +103,7 @@ function gradleVersionName(content: string) {
 	return matches[1];
 }
 
-async function createRelease(projectName: string, releaseConfig: ReleaseConfig, tagName: string, version: string): Promise<Release> {
+async function createRelease(projectName: string, releaseConfig: ReleaseConfig, tagName: string, version: string, publish: boolean): Promise<Release> {
 	const name = releaseConfig.name;
 	const suffix = version + (name === 'main' ? '' : `-${name}`);
 
@@ -108,16 +111,16 @@ async function createRelease(projectName: string, releaseConfig: ReleaseConfig,
 
 	console.info(`Creating release: ${suffix}`);
 
-	if (releaseConfig.patch) await releaseConfig.patch(patcher, rnDir);
+	process.chdir(rootDir);
+
+	console.info(`Running from: ${process.cwd()}`);
+
+	if (releaseConfig.patch) await releaseConfig.patch(patcher, rootDir);
 
 	const apkFilename = `joplin-v${suffix}.apk`;
 	const apkFilePath = `${releaseDir}/${apkFilename}`;
 	const downloadUrl = `https://github.com/laurent22/${projectName}/releases/download/${tagName}/${apkFilename}`;
 
-	process.chdir(rootDir);
-
-	console.info(`Running from: ${process.cwd()}`);
-
 	await execCommand('yarn install', { showStdout: false });
 	await execCommand('yarn tsc', { showStdout: false });
 	await execCommand('yarn buildParallel', { showStdout: false });
@@ -130,7 +133,7 @@ async function createRelease(projectName: string, releaseConfig: ReleaseConfig,
 	// A problem occurred evaluating project ':app'
 	// > /Users/laurent/src/joplin-new/packages/app-mobile/android/build-main/generated/autolinking/autolinking.json
 	// > (No such file or directory)
-	const buildDirName = name === 'main' ? 'build' : `build-${name}`;
+	const buildDirName = 'build'; // name === 'main' ? 'build' : `build-${name}`;
 	const buildDirBasePath = `${rnDir}/android/app/${buildDirName}`;
 	await remove(buildDirBasePath);
 
@@ -175,9 +178,10 @@ async function createRelease(projectName: string, releaseConfig: ReleaseConfig,
 	await patcher.restore();
 
 	return {
-		downloadUrl: downloadUrl,
+		downloadUrl: publish ? downloadUrl : '',
 		apkFilename: apkFilename,
 		apkFilePath: apkFilePath,
+		publish,
 	};
 }
 
@@ -192,6 +196,11 @@ const uploadToGitHubRelease = async (projectName: string, tagName: string, isPre
 
 	for (const releaseFilename in releaseFiles) {
 		const releaseFile = releaseFiles[releaseFilename];
+		if (!releaseFile.publish) {
+			console.info(`Skipping: ${releaseFile.apkFilename} (publishing is disabled)`);
+			continue;
+		}
+
 		const uploadUrl = uploadUrlTemplate.expand({ name: releaseFile.apkFilename });
 
 		const binaryBody = await readFile(releaseFile.apkFilePath);
@@ -214,9 +223,78 @@ const uploadToGitHubRelease = async (projectName: string, tagName: string, isPre
 	}
 };
 
+// const testPatch = async (releaseConfig:ReleaseConfig) => {
+// 	const patcher = new Patcher(`${rnDir}/patcher-work`);
+// 	await releaseConfig.patch(patcher, rootDir);
+// 	process.exit();
+// }
+
+const releaseConfigs: ReleaseConfig[] = [
+	{
+		name: 'main',
+		publish: true,
+	},
+
+	{
+		name: 'custom',
+		publish: false,
+		patch: require(`${homedir()}/joplin-credentials/android-black-icon.js`),
+	},
+
+	{
+		name: 'armeabi-v7a',
+		disabled: true,
+		publish: true,
+		patch: async (patcher, rootDir) => {
+			await patcher.updateFileContent(`${rootDir}/packages/app-mobile/android/app/build.gradle`, async (content: string) => {
+				content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "armeabi-v7a"');
+				return content;
+			});
+		},
+	},
+
+	{
+		name: 'x86',
+		disabled: true,
+		publish: true,
+		patch: async (patcher, rootDir) => {
+			await patcher.updateFileContent(`${rootDir}/packages/app-mobile/android/app/build.gradle`, async (content: string) => {
+				content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "x86"');
+				return content;
+			});
+		},
+	},
+
+	{
+		name: 'arm64-v8a',
+		disabled: true,
+		publish: true,
+		patch: async (patcher, rootDir) => {
+			await patcher.updateFileContent(`${rootDir}/packages/app-mobile/android/app/build.gradle`, async (content: string) => {
+				content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "arm64-v8a"');
+				return content;
+			});
+		},
+	},
+
+	{
+		name: 'x86_64',
+		disabled: true,
+		publish: true,
+		patch: async (patcher, rootDir) => {
+			await patcher.updateFileContent(`${rootDir}/packages/app-mobile/android/app/build.gradle`, async (content: string) => {
+				content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "x86_64"');
+				return content;
+			});
+		},
+	},
+];
+
 async function main() {
 	const argv = require('yargs').argv;
 
+	// await testPatch(releaseConfigs[1]);
+
 	await gitPullTry(false);
 
 	const isPreRelease = !('type' in argv) || argv.type === 'prerelease';
@@ -231,79 +309,20 @@ async function main() {
 	const version = gradleVersionName(newContent);
 	const tagName = `android-v${version}`;
 
-	const releaseConfigs: ReleaseConfig[] = [
-		{
-			name: 'main',
-		},
-
-		{
-			name: 'armeabi-v7a',
-			disabled: true,
-			patch: async (patcher, rnDir) => {
-				await patcher.updateFileContent(`${rnDir}/android/app/build.gradle`, async (content: string) => {
-					content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "armeabi-v7a"');
-					return content;
-				});
-			},
-		},
-
-		{
-			name: 'x86',
-			disabled: true,
-			patch: async (patcher, rnDir) => {
-				await patcher.updateFileContent(`${rnDir}/android/app/build.gradle`, async (content: string) => {
-					content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "x86"');
-					return content;
-				});
-			},
-		},
-
-		{
-			name: 'arm64-v8a',
-			disabled: true,
-			patch: async (patcher, rnDir) => {
-				await patcher.updateFileContent(`${rnDir}/android/app/build.gradle`, async (content: string) => {
-					content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "arm64-v8a"');
-					return content;
-				});
-			},
-		},
-
-		{
-			name: 'x86_64',
-			disabled: true,
-			patch: async (patcher, rnDir) => {
-				await patcher.updateFileContent(`${rnDir}/android/app/build.gradle`, async (content: string) => {
-					content = content.replace(/abiFilters "armeabi-v7a", "x86", "arm64-v8a", "x86_64"/, 'abiFilters "x86_64"');
-					return content;
-				});
-			},
-		},
-	];
-
 	const releaseFiles: Record<string, Release> = {};
 	const mainProjectName = 'joplin-android';
-	const modProjectName = 'joplin-android-mod';
 
 	for (const releaseConfig of releaseConfigs) {
 		if (releaseNameOnly && releaseConfig.name !== releaseNameOnly) continue;
 		if (releaseConfig.disabled) continue;
-		const projectName = releaseConfig.name === 'vosk' ? modProjectName : mainProjectName;
-		releaseFiles[releaseConfig.name] = await createRelease(projectName, releaseConfig, tagName, version);
+		releaseFiles[releaseConfig.name] = await createRelease(mainProjectName, releaseConfig, tagName, version, releaseConfig.publish);
 	}
 
 	console.info('Created releases:');
 	console.info(releaseFiles);
 
-	const voskRelease = releaseFiles['vosk'];
-	delete releaseFiles['vosk'];
-
 	await uploadToGitHubRelease(mainProjectName, tagName, isPreRelease, releaseFiles);
 
-	if (voskRelease) {
-		await uploadToGitHubRelease(modProjectName, tagName, isPreRelease, { 'vosk': voskRelease });
-	}
-
 	console.info(`Main download URL: ${releaseFiles['main'].downloadUrl}`);
 
 	const changelogPath = `${rootDir}/readme/about/changelog/android.md`;
