@@ -1,5 +1,5 @@
-import { execCommand } from '@joplin/utils';
 import { rootDir, gitPullTry, completeReleaseWithChangelog } from './tool-utils';
+import { versionPatch } from '@joplin/utils/version';
 
 const transcribeDir = `${rootDir}/packages/transcribe`;
 
@@ -7,7 +7,7 @@ async function main() {
 	await gitPullTry();
 
 	process.chdir(transcribeDir);
-	const version = (await execCommand('npm version patch')).trim();
+	const version = await versionPatch();
 	const versionSuffix = '';
 	const tagName = `transcribe-${version}${versionSuffix}`;
 
