@@ -1,5 +1,7 @@
 import Logger from '@joplin/utils/Logger';
 import { JobData } from '../../types';
+import resizeImageAndDeleteInput from '../utils/resizeImageAndDeleteInput';
+import { join } from 'path';
 
 const logger = Logger.create('createJob');
 
@@ -7,10 +9,16 @@ type CreateJobContext = {
 	storeImage: (filePath: string)=> Promise<string>;
 	sendToQueue: (data: JobData)=> Promise<string | null>;
 	filepath: string;
+	imageMaxDimension: number;
+	randomName: string;
 };
 
 const createJob = async (context: CreateJobContext) => {
-	const filePath = await context.storeImage(context.filepath);
+	const imageResizedPath = join('images', context.randomName);
+
+	await resizeImageAndDeleteInput(context.filepath, imageResizedPath, context.imageMaxDimension);
+
+	const filePath = await context.storeImage(imageResizedPath);
 
 	const jobId = await context.sendToQueue({ filePath });
 
