@@ -1,4 +1,6 @@
+import env from '../../env';
 import { ErrorBadRequest } from '../../errors';
+import createFilename from '../../services/createFilename';
 import { AppContext, JobData } from '../../types';
 import isFileAValidImage, { supportedImageFormat } from './isFileAValidImage';
 
@@ -24,6 +26,8 @@ export const parseCreateJobRequest = async (ctx: AppContext) => {
 		storeImage: (file: string) => ctx.storage.store(file),
 		sendToQueue: (data: JobData) => ctx.queue.send(data),
 		filepath: file.filepath,
+		imageMaxDimension: env().IMAGE_MAX_DIMENSION,
+		randomName: createFilename(),
 	};
 };
 
