@@ -3,7 +3,10 @@
 // added here, and should be based on dayjs (not moment)
 // -----------------------------------------------------------------------------------------------
 
-import * as dayjs from 'dayjs';
+import type * as dayjsImport from 'dayjs';
+import * as dayJsUtc from 'dayjs/plugin/utc';
+// A require() is needed here for this to work in React Native.
+const dayjs: typeof dayjsImport = require('dayjs');
 
 // Separating this into a type import and a require seems to be necessary to support mobile:
 // - import = require syntax doesn't work when bundling
@@ -64,6 +67,7 @@ export const Month = 30 * Day;
 
 function initDayJs() {
 	dayjs.extend(dayJsRelativeTime);
+	dayjs.extend(dayJsUtc);
 }
 
 initDayJs();
@@ -166,3 +170,13 @@ export const formatMsToDurationCompat = (ms: number) => {
 	const paddedSeconds = `${seconds}`.padStart(2, '0');
 	return `${minutes}:${paddedSeconds}`;
 };
+
+
+export const goBackInTime = (startDateMs: number, n: number, period: dayjsImport.ManipulateType) => {
+	return dayjs(startDateMs).subtract(n, period);
+};
+
+export const formatMsToUTC = (ms: number, format: string|null = null) => {
+	if (format === null) format = dateTimeFormat();
+	return dayjs(ms).utc().format(format);
+};
